Contributors
============

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-108-orange.svg)](#contributors)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/ayan-biswas0412"><img src="https://avatars.githubusercontent.com/u/52851184?v=4?s=100" width="100px;" alt=""/><br /><sub><b>AYAN BISWAS</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ayan-biswas0412" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/ABostrom"><img src="https://avatars0.githubusercontent.com/u/9571933?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Aaron Bostrom</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ABostrom" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=ABostrom" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=ABostrom" title="Tests">⚠️</a> <a href="#mentoring-ABostrom" title="Mentoring">🧑‍🏫</a></td>
    <td align="center"><a href="https://github.com/aaronreidsmith"><img src="https://avatars.githubusercontent.com/u/21350310?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Aaron Smith</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=aaronreidsmith" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/afzal442"><img src="https://avatars0.githubusercontent.com/u/11625672?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Afzal Ansari</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=afzal442" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=afzal442" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/bilal-196"><img src="https://avatars.githubusercontent.com/u/74570044?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ahmed Bilal</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=bilal-196" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/AidenRushbrooke"><img src="https://avatars0.githubusercontent.com/u/72034940?v=4?s=100" width="100px;" alt=""/><br /><sub><b>AidenRushbrooke</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=AidenRushbrooke" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=AidenRushbrooke" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://medium.com/@alexandra.amidon"><img src="https://avatars2.githubusercontent.com/u/17050655?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alexandra Amidon</b></sub></a><br /><a href="#blog-lynnssi" title="Blogposts">📝</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=lynnssi" title="Documentation">📖</a> <a href="#ideas-lynnssi" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/alwinw"><img src="https://avatars3.githubusercontent.com/u/16846521?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alwin</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=alwinw" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=alwinw" title="Code">💻</a> <a href="#maintenance-alwinw" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://github.com/akanz1"><img src="https://avatars3.githubusercontent.com/u/51492342?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Andreas Kanz</b></sub></a><br /><a href="#tutorial-akanz1" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/yard1/"><img src="https://avatars.githubusercontent.com/u/10364161?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Antoni Baum</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Yard1" title="Code">💻</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/ayushmaan-seth-4a96364a/"><img src="https://avatars1.githubusercontent.com/u/29939762?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ayushmaan Seth</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Ayushmaanseth" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3AAyushmaanseth" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Ayushmaanseth" title="Tests">⚠️</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Ayushmaanseth" title="Documentation">📖</a> <a href="#eventOrganizing-Ayushmaanseth" title="Event Organizing">📋</a> <a href="#tutorial-Ayushmaanseth" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/BandaSaiTejaReddy"><img src="https://avatars0.githubusercontent.com/u/31387911?v=4?s=100" width="100px;" alt=""/><br /><sub><b>BANDASAITEJAREDDY</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=BandaSaiTejaReddy" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=BandaSaiTejaReddy" title="Documentation">📖</a></td>
    <td align="center"><a href="https://bmurphyportfolio.netlify.com/"><img src="https://avatars2.githubusercontent.com/u/32182553?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Brian Murphy</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=bmurdata" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/vnmabus"><img src="https://avatars1.githubusercontent.com/u/2364173?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Carlos Ramos Carreño</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=vnmabus" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="http://cheuk.dev"><img src="https://avatars1.githubusercontent.com/u/28761465?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Cheuk Ting Ho</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Cheukting" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/ckastner"><img src="https://avatars.githubusercontent.com/u/15859947?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Christian Kastner</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ckastner" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Ackastner" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/ClaudiaSanches"><img src="https://avatars3.githubusercontent.com/u/28742178?v=4?s=100" width="100px;" alt=""/><br /><sub><b>ClaudiaSanches</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ClaudiaSanches" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=ClaudiaSanches" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://dhirschfeld.github.io/"><img src="https://avatars1.githubusercontent.com/u/881019?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Dave Hirschfeld</b></sub></a><br /><a href="#infra-dhirschfeld" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://github.com/davidbp"><img src="https://avatars3.githubusercontent.com/u/4223580?v=4?s=100" width="100px;" alt=""/><br /><sub><b>David Buchaca Prats</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=davidbp" title="Code">💻</a></td>
    <td align="center"><a href="http://www.uco.es/grupos/ayrna/index.php/es/publicaciones/articulos?publications_view_all=1&theses_view_all=0&projects_view_all=0&task=show&view=member&id=22"><img src="https://avatars1.githubusercontent.com/u/47889499?v=4?s=100" width="100px;" alt=""/><br /><sub><b>David Guijo Rubio</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=dguijo" title="Code">💻</a> <a href="#ideas-dguijo" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/DmitriyValetov"><img src="https://avatars0.githubusercontent.com/u/27976850?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Dmitriy Valetov</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=DmitriyValetov" title="Code">💻</a> <a href="#tutorial-DmitriyValetov" title="Tutorials">✅</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/Dbhasin1"><img src="https://avatars.githubusercontent.com/u/56479884?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Drishti Bhasin </b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Dbhasin1" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dsherry"><img src="https://avatars.githubusercontent.com/dsherry?s=100" width="100px;" alt=""/><br /><sub><b>Dylan Sherry</b></sub></a><br /><a href="#infra-dsherry" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://github.com/Emiliathewolf"><img src="https://avatars2.githubusercontent.com/u/22026218?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Emilia Rose</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Emiliathewolf" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Emiliathewolf" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/evanmiller29"><img src="https://avatars2.githubusercontent.com/u/8062590?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Evan Miller</b></sub></a><br /><a href="#tutorial-evanmiller29" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/flix6x"><img src="https://avatars.githubusercontent.com/u/30658763?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Felix Claessen</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=flix6x" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Aflix6x" title="Bug reports">🐛</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=flix6x" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/fkiraly"><img src="https://avatars1.githubusercontent.com/u/7985502?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Franz Kiraly</b></sub></a><br /><a href="#business-fkiraly" title="Business development">💼</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=fkiraly" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=fkiraly" title="Documentation">📖</a> <a href="#design-fkiraly" title="Design">🎨</a> <a href="#eventOrganizing-fkiraly" title="Event Organizing">📋</a> <a href="#example-fkiraly" title="Examples">💡</a> <a href="#financial-fkiraly" title="Financial">💵</a> <a href="#fundingFinding-fkiraly" title="Funding Finding">🔍</a> <a href="#ideas-fkiraly" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-fkiraly" title="Mentoring">🧑‍🏫</a> <a href="#projectManagement-fkiraly" title="Project Management">📆</a> <a href="#question-fkiraly" title="Answering Questions">💬</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3Afkiraly" title="Reviewed Pull Requests">👀</a> <a href="#talk-fkiraly" title="Talks">📢</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=fkiraly" title="Tests">⚠️</a> <a href="#tutorial-fkiraly" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/goastler"><img src="https://avatars0.githubusercontent.com/u/7059456?v=4?s=100" width="100px;" alt=""/><br /><sub><b>George Oastler</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=goastler" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=goastler" title="Tests">⚠️</a> <a href="#platform-goastler" title="Packaging/porting to new platform">📦</a> <a href="#example-goastler" title="Examples">💡</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=goastler" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://www.linkedin.com/in/gracewgao/"><img src="https://avatars0.githubusercontent.com/u/38268331?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Grace Gao</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=gracewgao" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Agracewgao" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/GuzalBulatova"><img src="https://avatars.githubusercontent.com/GuzalBulatova?s=100" width="100px;" alt=""/><br /><sub><b>Guzal Bulatova</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=GuzalBulatova" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=GuzalBulatova" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/HYang1996"><img src="https://avatars0.githubusercontent.com/u/44179303?v=4?s=100" width="100px;" alt=""/><br /><sub><b>HYang1996</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=HYang1996" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=HYang1996" title="Tests">⚠️</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=HYang1996" title="Documentation">📖</a> <a href="#tutorial-HYang1996" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/huayiwei/"><img src="https://avatars3.githubusercontent.com/u/22870735?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Huayi Wei</b></sub></a><br /><a href="#tutorial-huayicodes" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/Ifeanyi30"><img src="https://avatars.githubusercontent.com/u/49926145?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ifeanyi30</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Ifeanyi30" title="Code">💻</a></td>
    <td align="center"><a href="http://www.timeseriesclassification.com/"><img src="https://avatars0.githubusercontent.com/u/44509982?v=4?s=100" width="100px;" alt=""/><br /><sub><b>James Large</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=James-Large" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=James-Large" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=James-Large" title="Tests">⚠️</a> <a href="#infra-James-Large" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#maintenance-James-Large" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://github.com/jambo6"><img src="https://https://avatars.githubusercontent.com/jambo6?s=100" width="100px;" alt=""/><br /><sub><b>James Morrill</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=jambo6" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="http://www.timeseriesclassification.com"><img src="https://avatars1.githubusercontent.com/u/38794632?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jason Lines</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=jasonlines" title="Code">💻</a> <a href="#business-jasonlines" title="Business development">💼</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=jasonlines" title="Documentation">📖</a> <a href="#design-jasonlines" title="Design">🎨</a> <a href="#eventOrganizing-jasonlines" title="Event Organizing">📋</a> <a href="#fundingFinding-jasonlines" title="Funding Finding">🔍</a> <a href="#ideas-jasonlines" title="Ideas, Planning, & Feedback">🤔</a> <a href="#projectManagement-jasonlines" title="Project Management">📆</a> <a href="#question-jasonlines" title="Answering Questions">💬</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3Ajasonlines" title="Reviewed Pull Requests">👀</a> <a href="#talk-jasonlines" title="Talks">📢</a> <a href="#example-jasonlines" title="Examples">💡</a></td>
    <td align="center"><a href="https://github.com/whackteachers"><img src="https://avatars0.githubusercontent.com/u/33785383?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jason Pong</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=whackteachers" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=whackteachers" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://juanitorduz.github.io/"><img src="https://avatars1.githubusercontent.com/u/22996444?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Juan Orduz</b></sub></a><br /><a href="#tutorial-juanitorduz" title="Tutorials">✅</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=juanitorduz" title="Documentation">📖</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/julianarn/"><img src="https://avatars.githubusercontent.com/u/19613567?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Juliana</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=julramos" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/kanand77"><img src="https://avatars.githubusercontent.com/kanand77?s=100" width="100px;" alt=""/><br /><sub><b>Kavin Anand</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=kanand77" title="Documentation">📖</a></td>
    <td align="center"><a href="https://whitakerlab.github.io/"><img src="https://avatars1.githubusercontent.com/u/3626306?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kirstie Whitaker</b></sub></a><br /><a href="#ideas-KirstieJane" title="Ideas, Planning, & Feedback">🤔</a> <a href="#fundingFinding-KirstieJane" title="Funding Finding">🔍</a></td>
    <td align="center"><a href="https://github.com/krumeto"><img src="https://avatars3.githubusercontent.com/u/11272436?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Krum Arnaudov</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Akrumeto" title="Bug reports">🐛</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=krumeto" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/koralturkk"><img src="https://avatars2.githubusercontent.com/u/18037789?s=460&v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kutay Koralturk</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=koralturkk" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Akoralturkk" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/ltsaprounis"><img src="https://avatars.githubusercontent.com/u/64217214?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Leonidas Tsaprounis</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ltsaprounis" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Altsaprounis" title="Bug reports">🐛</a></td>
    <td align="center"><a href="http://lpantano.github.io/"><img src="https://avatars2.githubusercontent.com/u/1621788?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Lorena Pantano</b></sub></a><br /><a href="#ideas-lpantano" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/ltoniazzi"><img src="https://avatars.githubusercontent.com/u/61414566?s=100" width="100px;" alt=""/><br /><sub><b>Lorenzo Toniazzi</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ltoniazzi" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/Lovkush-A"><img src="https://avatars.githubusercontent.com/u/25344832?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Lovkush</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Lovkush-A" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Lovkush-A" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/luiszugasti"><img src="https://avatars.githubusercontent.com/u/11198457?s=460&u=0645b72683e491824aca16db9702f1d3eb990389&v=4?s=100" width="100px;" alt=""/><br /><sub><b>Luis Zugasti</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=luiszugasti" title="Documentation">📖</a></td>
    <td align="center"><a href="http://marcelotryle.com"><img src="https://avatars3.githubusercontent.com/u/7353520?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Marcelo Trylesinski</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Kludex" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/MarcoGorelli"><img src="https://avatars2.githubusercontent.com/u/33491632?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Marco Gorelli</b></sub></a><br /><a href="#infra-MarcoGorelli" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://twitter.com/marielli"><img src="https://avatars2.githubusercontent.com/u/13499809?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Marielle</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=marielledado" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=marielledado" title="Code">💻</a> <a href="#ideas-marielledado" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/mloning"><img src="https://avatars3.githubusercontent.com/u/21020482?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Markus Löning</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=mloning" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=mloning" title="Tests">⚠️</a> <a href="#maintenance-mloning" title="Maintenance">🚧</a> <a href="#platform-mloning" title="Packaging/porting to new platform">📦</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3Amloning" title="Reviewed Pull Requests">👀</a> <a href="#infra-mloning" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#example-mloning" title="Examples">💡</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Amloning" title="Bug reports">🐛</a> <a href="#tutorial-mloning" title="Tutorials">✅</a> <a href="#business-mloning" title="Business development">💼</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=mloning" title="Documentation">📖</a> <a href="#design-mloning" title="Design">🎨</a> <a href="#eventOrganizing-mloning" title="Event Organizing">📋</a> <a href="#fundingFinding-mloning" title="Funding Finding">🔍</a> <a href="#ideas-mloning" title="Ideas, Planning, & Feedback">🤔</a> <a href="#projectManagement-mloning" title="Project Management">📆</a> <a href="#question-mloning" title="Answering Questions">💬</a> <a href="#talk-mloning" title="Talks">📢</a> <a href="#mentoring-mloning" title="Mentoring">🧑‍🏫</a> <a href="#video-mloning" title="Videos">📹</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/martin-walter-1a33b3114/"><img src="https://avatars0.githubusercontent.com/u/29627036?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Martin Walter</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=aiwalter" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Aaiwalter" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/martinagvilas"><img src="https://avatars2.githubusercontent.com/u/37339384?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Martina G. Vilas</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3Amartinagvilas" title="Reviewed Pull Requests">👀</a> <a href="#ideas-martinagvilas" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="http://www.timeseriesclassification.com"><img src="https://avatars0.githubusercontent.com/u/25731235?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Matthew Middlehurst</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=MatthewMiddlehurst" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=MatthewMiddlehurst" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=MatthewMiddlehurst" title="Tests">⚠️</a> <a href="#tutorial-MatthewMiddlehurst" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/Hephaest"><img src="https://avatars2.githubusercontent.com/u/37981444?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Miao Cai</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3AHephaest" title="Bug reports">🐛</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Hephaest" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/MichalChromcak"><img src="https://avatars1.githubusercontent.com/u/12393430?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Michal Chromcak</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=MichalChromcak" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=MichalChromcak" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=MichalChromcak" title="Tests">⚠️</a> <a href="#tutorial-MichalChromcak" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://mo-saif.github.io/"><img src="https://avatars0.githubusercontent.com/u/27867617?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Mohammed Saif Kazamel</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3AMo-Saif" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://moradisten.github.io/"><img src="https://avatars.githubusercontent.com/u/29915156?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Morad :)</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=moradabaz" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=moradabaz" title="Tests">⚠️</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=moradabaz" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/Multivin12"><img src="https://avatars3.githubusercontent.com/u/36476633?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Multivin12</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Multivin12" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Multivin12" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/ngupta23"><img src="https://avatars0.githubusercontent.com/u/33585645?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Nikhil Gupta</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ngupta23" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Angupta23" title="Bug reports">🐛</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=ngupta23" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/ninfueng"><img src="https://avatars2.githubusercontent.com/u/28499769?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ninnart Fuengfusin</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ninfueng" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/kachayev"><img src="https://avatars.githubusercontent.com/u/485647?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Oleksii Kachaiev</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=kachayev" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=kachayev" title="Tests">⚠️</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/prockenschaub"><img src="https://avatars0.githubusercontent.com/u/15381732?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Patrick Rockenschaub</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=prockenschaub" title="Code">💻</a> <a href="#design-prockenschaub" title="Design">🎨</a> <a href="#ideas-prockenschaub" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=prockenschaub" title="Tests">⚠️</a></td>
    <td align="center"><a href="http://www2.informatik.hu-berlin.de/~schaefpa/"><img src="https://avatars0.githubusercontent.com/u/7783034?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Patrick Schäfer</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=patrickzib" title="Code">💻</a> <a href="#tutorial-patrickzib" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://ber.gp"><img src="https://avatars1.githubusercontent.com/u/9824244?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Paul</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Pangoraw" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/Piyush1729"><img src="https://avatars2.githubusercontent.com/u/64950012?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Piyush1729</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Piyush1729" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3APiyush1729" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/Quaterion"><img src="https://avatars2.githubusercontent.com/u/23200273?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Quaterion</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3AQuaterion" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/Riyabelle25"><img src="https://avatars.githubusercontent.com/u/55790848?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Riya Elizabeth John</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=Riyabelle25" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Riyabelle25" title="Tests">⚠️</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=Riyabelle25" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/rnkuhns"><img src="https://avatars0.githubusercontent.com/u/26907244?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ryan Kuhns</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=RNKuhns" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=RNKuhns" title="Documentation">📖</a> <a href="#tutorial-RNKuhns" title="Tutorials">✅</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://sajay.online"><img src="https://avatars2.githubusercontent.com/u/25329624?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Sajaysurya Ganesh</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=sajaysurya" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=sajaysurya" title="Documentation">📖</a> <a href="#design-sajaysurya" title="Design">🎨</a> <a href="#example-sajaysurya" title="Examples">💡</a> <a href="#ideas-sajaysurya" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=sajaysurya" title="Tests">⚠️</a> <a href="#tutorial-sajaysurya" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/satya-pattnaik-77a430144/"><img src="https://avatars.githubusercontent.com/u/22102468?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Satya Prakash Pattnaik</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=satya-pattnaik" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/dasgupsa"><img src="https://avatars2.githubusercontent.com/u/10398956?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Saurabh Dasgupta</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=dasgupsa" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/SebasKoel"><img src="https://avatars3.githubusercontent.com/u/66252156?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Sebastiaan Koel</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=SebasKoel" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=SebasKoel" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/SveaMeyer13"><img src="https://avatars.githubusercontent.com/u/46671894?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Svea Marie Meyer</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=SveaMeyer13" title="Documentation">📖</a></td>
    <td align="center"><a href="https://thayeylolu.github.io/portfolio/"><img src="https://avatars.githubusercontent.com/u/13348874?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Taiwo Owoseni</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=thayeylolu" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/lnthach"><img src="https://avatars0.githubusercontent.com/u/7788363?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Thach Le Nguyen</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=lnthach" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=lnthach" title="Tests">⚠️</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/tombh"><img src="https://avatars.githubusercontent.com/u/160835?s=80&v=4?s=100" width="100px;" alt=""/><br /><sub><b>Thomas Buckley-Houston</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Atombh" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/tch"><img src="https://avatars3.githubusercontent.com/u/184076?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tomasz Chodakowski</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=tch" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=tch" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Atch" title="Bug reports">🐛</a></td>
    <td align="center"><a href="http://www.timeseriesclassification.com"><img src="https://avatars1.githubusercontent.com/u/9594042?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tony Bagnall</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=TonyBagnall" title="Code">💻</a> <a href="#business-TonyBagnall" title="Business development">💼</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=TonyBagnall" title="Documentation">📖</a> <a href="#design-TonyBagnall" title="Design">🎨</a> <a href="#eventOrganizing-TonyBagnall" title="Event Organizing">📋</a> <a href="#fundingFinding-TonyBagnall" title="Funding Finding">🔍</a> <a href="#ideas-TonyBagnall" title="Ideas, Planning, & Feedback">🤔</a> <a href="#projectManagement-TonyBagnall" title="Project Management">📆</a> <a href="#question-TonyBagnall" title="Answering Questions">💬</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3ATonyBagnall" title="Reviewed Pull Requests">👀</a> <a href="#talk-TonyBagnall" title="Talks">📢</a> <a href="#data-TonyBagnall" title="Data">🔣</a></td>
    <td align="center"><a href="https://github.com/utsavcoding"><img src="https://avatars3.githubusercontent.com/u/55446385?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Utsav Kumar Tiwari</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=utsavcoding" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=utsavcoding" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/ViktorKaz"><img src="https://avatars0.githubusercontent.com/u/33499138?v=4?s=100" width="100px;" alt=""/><br /><sub><b>ViktorKaz</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=ViktorKaz" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=ViktorKaz" title="Documentation">📖</a> <a href="#design-ViktorKaz" title="Design">🎨</a></td>
    <td align="center"><a href="https://github.com/magittan"><img src="https://avatars0.githubusercontent.com/u/14024202?v=4?s=100" width="100px;" alt=""/><br /><sub><b>William Zheng</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=magittan" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=magittan" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/yashlamba"><img src="https://avatars.githubusercontent.com/u/44164398?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Yash Lamba</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=yashlamba" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/xuyxu"><img src="https://avatars2.githubusercontent.com/u/22359569?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Yi-Xuan Xu</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=xuyxu" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=xuyxu" title="Tests">⚠️</a> <a href="#maintenance-xuyxu" title="Maintenance">🚧</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=xuyxu" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/aa25desh"><img src="https://avatars1.githubusercontent.com/u/29518290?v=4?s=100" width="100px;" alt=""/><br /><sub><b>aa25desh</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=aa25desh" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Aaa25desh" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/abandus"><img src="https://avatars2.githubusercontent.com/u/46486474?v=4?s=100" width="100px;" alt=""/><br /><sub><b>abandus</b></sub></a><br /><a href="#ideas-abandus" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=abandus" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/angus924"><img src="https://avatars0.githubusercontent.com/u/55837131?v=4?s=100" width="100px;" alt=""/><br /><sub><b>angus924</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=angus924" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=angus924" title="Tests">⚠️</a> <a href="#tutorial-angus924" title="Tutorials">✅</a></td>
    <td align="center"><a href="https://github.com/big-o"><img src="https://avatars1.githubusercontent.com/u/1134151?v=4?s=100" width="100px;" alt=""/><br /><sub><b>big-o</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=big-o" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=big-o" title="Tests">⚠️</a> <a href="#design-big-o" title="Design">🎨</a> <a href="#ideas-big-o" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/alan-turing-institute/sktime/pulls?q=is%3Apr+reviewed-by%3Abig-o" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-big-o" title="Tutorials">✅</a> <a href="#mentoring-big-o" title="Mentoring">🧑‍🏫</a></td>
    <td align="center"><a href="https://github.com/brettkoonce"><img src="https://avatars2.githubusercontent.com/u/11281814?v=4?s=100" width="100px;" alt=""/><br /><sub><b>brett koonce</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=brettkoonce" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/btrtts"><img src="https://avatars3.githubusercontent.com/u/66252156?v=4?s=100" width="100px;" alt=""/><br /><sub><b>btrtts</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=btrtts" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/chizzi25"><img src="https://avatars3.githubusercontent.com/u/67911243?v=4?s=100" width="100px;" alt=""/><br /><sub><b>chizzi25</b></sub></a><br /><a href="#blog-chizzi25" title="Blogposts">📝</a></td>
    <td align="center"><a href="https://github.com/chrisholder"><img src="https://avatars.githubusercontent.com/u/4674372?v=4?s=100" width="100px;" alt=""/><br /><sub><b>chrisholder</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=chrisholder" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=chrisholder" title="Tests">⚠️</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=chrisholder" title="Documentation">📖</a> <a href="#design-chrisholder" title="Design">🎨</a> <a href="#example-chrisholder" title="Examples">💡</a></td>
    <td align="center"><a href="https://github.com/hamzahiqb"><img src="https://avatars3.githubusercontent.com/u/10302415?v=4?s=100" width="100px;" alt=""/><br /><sub><b>hamzahiqb</b></sub></a><br /><a href="#infra-hamzahiqb" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://github.com/hiqbal2"><img src="https://avatars3.githubusercontent.com/u/10302415?v=4?s=100" width="100px;" alt=""/><br /><sub><b>hiqbal2</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=hiqbal2" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/jesellier"><img src="https://avatars0.githubusercontent.com/u/51952076?v=4?s=100" width="100px;" alt=""/><br /><sub><b>jesellier</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=jesellier" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/jschemm"><img src="https://avatars.githubusercontent.com/u/81151346?v=4?s=100" width="100px;" alt=""/><br /><sub><b>jschemm</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=jschemm" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/kkoziara"><img src="https://avatars1.githubusercontent.com/u/4346849?v=4?s=100" width="100px;" alt=""/><br /><sub><b>kkoziara</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=kkoziara" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Akkoziara" title="Bug reports">🐛</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/matteogales"><img src="https://avatars0.githubusercontent.com/u/9269326?v=4?s=100" width="100px;" alt=""/><br /><sub><b>matteogales</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=matteogales" title="Code">💻</a> <a href="#design-matteogales" title="Design">🎨</a> <a href="#ideas-matteogales" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/oleskiewicz"><img src="https://avatars1.githubusercontent.com/u/5682158?v=4?s=100" width="100px;" alt=""/><br /><sub><b>oleskiewicz</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=oleskiewicz" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=oleskiewicz" title="Documentation">📖</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=oleskiewicz" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/pabworks"><img src="https://avatars.githubusercontent.com/u/32725127?v=4?s=100" width="100px;" alt=""/><br /><sub><b>pabworks</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=pabworks" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=pabworks" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/raishubham1"><img src="https://avatars3.githubusercontent.com/u/29356417?v=4?s=100" width="100px;" alt=""/><br /><sub><b>raishubham1</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=raishubham1" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/simone-pignotti"><img src="https://avatars1.githubusercontent.com/u/44410066?v=4?s=100" width="100px;" alt=""/><br /><sub><b>simone-pignotti</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=simone-pignotti" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/issues?q=author%3Asimone-pignotti" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/sophijka"><img src="https://avatars2.githubusercontent.com/u/47450591?v=4?s=100" width="100px;" alt=""/><br /><sub><b>sophijka</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=sophijka" title="Documentation">📖</a> <a href="#maintenance-sophijka" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://github.com/sri1419"><img src="https://avatars2.githubusercontent.com/u/65078278?v=4?s=100" width="100px;" alt=""/><br /><sub><b>sri1419</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=sri1419" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/vedazeren"><img src="https://avatars3.githubusercontent.com/u/63582874?v=4?s=100" width="100px;" alt=""/><br /><sub><b>vedazeren</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=vedazeren" title="Code">💻</a> <a href="https://github.com/alan-turing-institute/sktime/commits?author=vedazeren" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/vincent-nich12"><img src="https://avatars3.githubusercontent.com/u/36476633?v=4?s=100" width="100px;" alt=""/><br /><sub><b>vincent-nich12</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=vincent-nich12" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/vollmersj"><img src="https://avatars2.githubusercontent.com/u/12613127?v=4?s=100" width="100px;" alt=""/><br /><sub><b>vollmersj</b></sub></a><br /><a href="https://github.com/alan-turing-institute/sktime/commits?author=vollmersj" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
